@@ -155,7 +155,7 @@ class BaseApiWrapper:
             self.page_urls[page + 1] = response.json().get('@odata.nextLink', '__none__')
             return response.json()
         else:
-            raise D365ApiError({'response_status_code': response.status_code, 'response_data': response.json()})
+            raise D365ApiError({'response_status_code': response.status_code, 'response_data': response.content})
 
     def get_next_page(self):
         if self.current_page:
